"""
CLI publish 命令实现

提供用户友好的发布命令接口，支持：
- 发布 Docker 镜像到 registry
- 通知 Node Server 部署
- 验证发布状态
- 清晰的进度和错误提示
"""

import asyncio
import sys
from pathlib import Path
from typing import Optional

from ..build_system.build_manager import BuildManager, BuildManagerError
from ..build_system.cloud_function_client import CloudFunctionClient, CloudFunctionError
from ..build_system.config_provider import ConfigProvider
from ..build_system.docker_client import DockerClient, DockerError
from ..build_system.publish_manager import PublishManager, PublishManagerError


def publish_command(
    skip_build: bool = False,
    config: Optional[str] = None,
    version: Optional[str] = None,
    namespace: Optional[str] = None,
    verify: bool = True,
    env_file: Optional[str] = None,
) -> bool:
    """
    执行发布命令

    Args:
        skip_build: 跳过构建，使用现有镜像
        config: 配置文件路径（可选）
        version: 指定版本号（可选）
        namespace: 镜像命名空间（可选）
        verify: 发布后验证部署状态（默认开启）
        env_file: 环境变量文件路径（默认: .env）

    Returns:
        True 如果发布成功，False 否则
    """
    print("🚀 开始发布智能体镜像...\n")

    # 获取项目目录（当前工作目录）
    project_dir = Path.cwd()

    # 验证项目目录
    if not (project_dir / "pyproject.toml").exists():
        print("❌ 错误: 当前目录不包含 pyproject.toml 文件")
        print("   请确保在项目根目录运行发布命令。")
        print()
        print("💡 提示:")
        print("   cd your-agent-project")
        print("   uni-agent publish")
        return False

    try:
        # 初始化配置提供者
        config_provider = ConfigProvider()

        # 如果指定了配置文件，加载配置
        if config:
            config_path = Path(config)
            if not config_path.exists():
                print(f"❌ 配置文件不存在: {config}")
                return False
            config_provider.load_from_file(config_path)

        # 初始化 Docker 客户端
        docker_client = DockerClient(verbose=True)

        # 检查 Docker 是否可用
        if not docker_client.is_docker_available():
            print("❌ Docker daemon 不可用")
            print()
            print("💡 解决方案:")
            print("   • macOS: 启动 Docker Desktop")
            print("   • Linux: sudo systemctl start docker")
            print("   • Windows: 启动 Docker Desktop")
            print("   • 检查 Docker 权限: sudo usermod -aG docker $USER")
            return False

        # 初始化构建管理器
        build_manager = BuildManager(
            project_dir=project_dir,
            docker_client=docker_client,
        )

        # 如果指定了版本，更新构建管理器的版本
        if version:
            build_manager.project_config["version"] = version

        # 初始化云函数客户端（如果需要）
        cloud_function_url = config_provider.get_cloud_function_url()
        if cloud_function_url:
            cloud_client = CloudFunctionClient(base_url=cloud_function_url)
        else:
            # 本地配置完整，不需要云函数
            cloud_client = CloudFunctionClient(base_url="http://localhost")  # Dummy URL

        # 初始化发布管理器
        publish_manager = PublishManager(
            config_provider=config_provider,
            cloud_client=cloud_client,
            build_manager=build_manager,
            docker_client=docker_client,
        )

        # 执行发布流程（异步）
        result = asyncio.run(publish_manager.publish(skip_build=skip_build, env_file=env_file))

        if result["success"]:
            print("\n✅ 发布成功！")
            return True
        else:
            print("\n❌ 发布失败")
            return False

    except PublishManagerError as e:
        print(f"❌ 发布失败: {e}")
        print()
        print("💡 常见问题:")
        print("   • 检查 ROBOT_APPKEY 是否正确配置")
        print("   • 确保网络可访问云函数和 registry")
        print("   • 验证 Node Server 是否运行")
        return False

    except CloudFunctionError as e:
        print(f"❌ 云函数错误: {e}")
        print()
        print("💡 排查建议:")
        print("   • 检查 CLOUD_FUNCTION_URL 配置")
        print("   • 验证 ROBOT_APPKEY 是否有效")
        print("   • 确保网络连接正常")
        return False

    except BuildManagerError as e:
        print(f"❌ 构建失败: {e}")
        print()
        print("💡 常见问题:")
        print("   • 检查 pyproject.toml 格式是否正确")
        print("   • 确保项目名称和版本已定义")
        print("   • 检查 Dockerfile 语法（如果自定义）")
        return False

    except DockerError as e:
        print(f"❌ Docker 错误: {e}")
        print()
        print("💡 排查建议:")
        print("   • 检查 Docker daemon 是否运行")
        print("   • 检查磁盘空间是否充足")
        print("   • 尝试清理旧镜像: docker system prune")
        return False

    except KeyboardInterrupt:
        print("\n⏸️  发布已取消")
        return False

    except Exception as e:
        print(f"❌ 未知错误: {e}")
        print("   请检查日志或联系支持团队。")
        return False


def add_publish_command(subparsers):
    """
    添加 publish 命令到 argparse 子解析器

    Args:
        subparsers: argparse 子解析器对象
    """
    publish_parser = subparsers.add_parser(
        "publish",
        help="发布智能体镜像到云端",
        description="发布智能体 Docker 镜像到 registry，并通知 Node Server 部署",
    )

    publish_parser.add_argument(
        "--skip-build",
        action="store_true",
        help="跳过构建，直接使用现有镜像发布",
    )

    publish_parser.add_argument(
        "--config",
        "-c",
        type=str,
        default=None,
        help="指定配置文件路径（如 .env 文件）",
    )

    publish_parser.add_argument(
        "--version",
        "-v",
        type=str,
        default=None,
        help="指定镜像版本号（如 1.0.0）。如果不指定，将使用 pyproject.toml 中的版本。",
    )

    publish_parser.add_argument(
        "--namespace",
        "-n",
        type=str,
        default=None,
        help="指定镜像命名空间（如 robots）。如果不指定，使用云函数返回的默认值。",
    )

    publish_parser.add_argument(
        "--verify",
        action="store_true",
        default=True,
        help="发布后验证部署状态（默认开启）",
    )

    publish_parser.add_argument(
        "--no-verify",
        dest="verify",
        action="store_false",
        help="跳过发布后验证",
    )

    publish_parser.add_argument(
        "--env-file",
        type=str,
        default=None,
        help="环境变量文件路径（默认: .env，生产环境可使用 .env.prod）",
    )

    publish_parser.set_defaults(
        func=lambda args: publish_command(
            skip_build=args.skip_build,
            config=args.config,
            version=args.version,
            namespace=args.namespace,
            verify=args.verify,
            env_file=args.env_file,
        )
    )


__all__ = ["publish_command", "add_publish_command"]



"""配置管理"""

import logging
import os
from pathlib import Path
from typing import Any, Dict, Optional, Union

try:
    from dotenv import load_dotenv

    DOTENV_AVAILABLE = True
except ImportError:
    DOTENV_AVAILABLE = False


class Config:
    """配置管理类

    支持环境变量、配置文件和构造参数的配置方式，
    按优先级：构造参数 > 环境变量 > 默认值
    """

    def __init__(self, **kwargs):
        """初始化配置

        Args:
            **kwargs: 配置参数
        """
        # 自动加载 .env 文件
        self._load_dotenv()
        self._config = kwargs

    def _load_dotenv(self):
        """加载 .env 文件"""
        if not DOTENV_AVAILABLE:
            return

        # 查找 .env 文件的位置
        # 1. 当前工作目录
        # 2. 脚本所在目录
        # 3. 项目根目录（查找包含 setup.py 的目录）

        search_paths = [
            Path.cwd(),  # 当前工作目录
            Path(__file__).parent.parent.parent,  # uni-agent-sdk 根目录
        ]

        # 添加项目根目录（查找包含 setup.py 的目录）
        current = Path.cwd()
        while current != current.parent:
            if (current / "setup.py").exists():
                search_paths.insert(0, current)
                break
            current = current.parent

        # 尝试加载 .env 文件
        for path in search_paths:
            env_file = path / ".env"
            if env_file.exists():
                load_dotenv(env_file)
                break

    def get(self, key: str, default: Any = None) -> Any:
        """获取配置值

        Args:
            key: 配置键
            default: 默认值

        Returns:
            配置值
        """
        # 优先级：构造参数 > 环境变量 > 默认值
        if key in self._config:
            return self._config[key]

        env_key = key.upper()
        env_value = os.getenv(env_key)
        if env_value is not None:
            return env_value

        return default

    def get_bool(self, key: str, default: bool = False) -> bool:
        """获取布尔配置值"""
        value = self.get(key, default)
        if isinstance(value, bool):
            return value
        if isinstance(value, str):
            return value.lower() in ("true", "1", "yes", "on")
        return bool(value)

    def get_int(self, key: str, default: int = 0) -> int:
        """获取整数配置值"""
        value = self.get(key, default)
        try:
            return int(value)
        except (ValueError, TypeError):
            return default

    def get_float(self, key: str, default: float = 0.0) -> float:
        """获取浮点数配置值"""
        value = self.get(key, default)
        try:
            return float(value)
        except (ValueError, TypeError):
            return default

    # 平台配置
    @property
    def platform_base_url(self) -> str:
        """平台API基础URL"""
        return self.get(
            "platform_base_url",
            "https://fc-mp-8234fa2c-3eb4-4a22-8a8c-9a0ee3e97513.next.bspapp.com",
        )

    @property
    def connectcode(self) -> str:
        """平台连接代码 - S2S认证必需"""
        return self.get("connectcode", "")

    # RabbitMQ配置
    @property
    def rabbitmq_host(self) -> str:
        """RabbitMQ主机"""
        return self.get("rabbitmq_host", "115.190.75.7")

    @property
    def rabbitmq_port(self) -> int:
        """RabbitMQ端口"""
        return self.get_int("rabbitmq_port", 5673)

    @property
    def rabbitmq_vhost(self) -> str:
        """RabbitMQ虚拟主机"""
        return self.get("rabbitmq_vhost", "/dev")

    @property
    def rabbitmq_user(self) -> str:
        """RabbitMQ用户名"""
        return self.get("rabbitmq_username", "guest")

    @property
    def rabbitmq_password(self) -> str:
        """RabbitMQ密码"""
        return self.get("rabbitmq_password", "guest")

    # LLM配置
    @property
    def openrouter_api_key(self) -> Optional[str]:
        """OpenRouter API密钥"""
        return self.get("openrouter_api_key")

    @property
    def openrouter_base_url(self) -> str:
        """OpenRouter API基础URL"""
        return self.get("openrouter_base_url", "https://openrouter.ai/api/v1")

    @property
    def kimi_api_key(self) -> Optional[str]:
        """Kimi API密钥"""
        return self.get("kimi_api_key")

    @property
    def kimi_base_url(self) -> str:
        """Kimi API基础URL"""
        return self.get("kimi_base_url", "https://api.moonshot.cn/v1")

    @property
    def default_model(self) -> str:
        """默认LLM模型"""
        return self.get("default_model", "kimi-k2-turbo-preview")

    @property
    def default_temperature(self) -> float:
        """默认温度参数"""
        return self.get_float("default_temperature", 0.7)

    @property
    def default_max_tokens(self) -> int:
        """默认最大token数"""
        return self.get_int("default_max_tokens", 1000)

    # HTTP配置
    @property
    def http_timeout(self) -> int:
        """HTTP超时时间（秒）"""
        return self.get_int("http_timeout", 30)

    @property
    def http_connect_timeout(self) -> int:
        """HTTP连接超时时间（秒）"""
        return self.get_int("http_connect_timeout", 10)

    @property
    def http_retry_times(self) -> int:
        """HTTP重试次数"""
        return self.get_int("http_retry_times", 3)

    # 日志配置
    @property
    def log_level(self) -> str:
        """日志级别"""
        level = self.get("log_level", "INFO").upper()
        return getattr(logging, level, logging.INFO)

    @property
    def log_format(self) -> str:
        """日志格式"""
        return self.get(
            "log_format", "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
        )

    # 文件服务配置
    @property
    def upload_base_url(self) -> str:
        """文件上传基础URL"""
        return self.get("upload_base_url", "https://upload.example.com")

    @property
    def download_dir(self) -> str:
        """下载目录"""
        return self.get("download_dir", "./downloads")

    @property
    def max_file_size(self) -> int:
        """最大文件大小（字节）"""
        return self.get_int("max_file_size", 100 * 1024 * 1024)  # 100MB

    # 性能配置
    @property
    def max_workers(self) -> int:
        """最大工作线程数"""
        return self.get_int("max_workers", 4)

    @property
    def message_queue_size(self) -> int:
        """消息队列大小"""
        return self.get_int("message_queue_size", 100)

    @property
    def prefetch_count(self) -> int:
        """RabbitMQ预取消息数"""
        return self.get_int("prefetch_count", 1)

    # 安全配置
    @property
    def enable_signature_verify(self) -> bool:
        """是否启用签名验证"""
        return self.get_bool("enable_signature_verify", True)

    # 文件服务配置
    @property
    def file_upload_retry_times(self) -> int:
        """文件上传重试次数"""
        return self.get_int("file_upload_retry_times", 3)

    @property
    def file_upload_timeout(self) -> int:
        """文件上传超时时间（秒）"""
        return self.get_int("file_upload_timeout", 60)

    # 消息服务配置
    @property
    def message_retry_times(self) -> int:
        """消息发送重试次数"""
        return self.get_int("message_retry_times", 3)

    @property
    def message_max_retries(self) -> int:
        """消息处理最大重试次数（用于消息处理失败时的重试）"""
        return self.get_int("message_max_retries", 3)

    @property
    def message_retry_delays(self) -> list:
        """消息重试延迟（秒）- 指数退避策略

        默认为 [1, 2, 4] 表示 1秒、2秒、4秒的延迟
        """
        delays_str = self.get("message_retry_delays", "1,2,4")
        try:
            return [int(d.strip()) for d in delays_str.split(",")]
        except (ValueError, AttributeError):
            return [1, 2, 4]

    @property
    def enable_dead_letter_queue(self) -> bool:
        """是否启用死信队列（重试失败后发送）"""
        return self.get_bool("enable_dead_letter_queue", True)

    @property
    def enable_markdown_processing(self) -> bool:
        """是否启用Markdown处理"""
        return self.get_bool("enable_markdown_processing", True)

    @property
    def enable_html_reports(self) -> bool:
        """是否启用HTML报告功能"""
        return self.get_bool("enable_html_reports", True)

    @property
    def signature_expire_time(self) -> int:
        """签名过期时间（秒）"""
        return self.get_int("signature_expire_time", 300)

    def validate(self) -> Dict[str, str]:
        """验证配置

        Returns:
            验证错误信息字典，空字典表示验证通过
        """
        errors = {}

        # 验证必需配置 - 至少需要一个 AI API 密钥
        if not self.openrouter_api_key and not self.kimi_api_key:
            errors["ai_api_key"] = (
                "需要设置 OpenRouter API 密钥或 Kimi API 密钥其中之一"
            )

        if not self.rabbitmq_host:
            errors["rabbitmq_host"] = "RabbitMQ主机未设置"

        if not self.platform_base_url:
            errors["platform_base_url"] = "平台API基础URL未设置"

        # 验证CONNECTCODE必需配置（S2S认证必需）
        if not self.connectcode:
            errors["connectcode"] = (
                "CONNECTCODE是S2S认证的必需配置，无法与uni-im云函数通信"
            )

        # 验证数值范围
        if self.http_timeout <= 0:
            errors["http_timeout"] = "HTTP超时时间必须大于0"

        if self.default_temperature < 0 or self.default_temperature > 2:
            errors["default_temperature"] = "温度参数必须在0-2之间"

        if self.default_max_tokens <= 0:
            errors["default_max_tokens"] = "最大token数必须大于0"

        # 验证文件配置
        if self.max_file_size <= 0:
            errors["max_file_size"] = "最大文件大小必须大于0"

        if self.file_upload_retry_times < 0:
            errors["file_upload_retry_times"] = "文件上传重试次数不能小于0"

        if self.message_retry_times < 0:
            errors["message_retry_times"] = "消息重试次数不能小于0"

        return errors

    def to_dict(self) -> Dict[str, Any]:
        """转换为字典"""
        return {
            "platform_base_url": self.platform_base_url,
            "rabbitmq_host": self.rabbitmq_host,
            "rabbitmq_port": self.rabbitmq_port,
            "rabbitmq_vhost": self.rabbitmq_vhost,
            "rabbitmq_user": self.rabbitmq_user,
            "openrouter_base_url": self.openrouter_base_url,
            "default_model": self.default_model,
            "default_temperature": self.default_temperature,
            "default_max_tokens": self.default_max_tokens,
            "http_timeout": self.http_timeout,
            "log_level": logging.getLevelName(self.log_level),
            "max_workers": self.max_workers,
            "enable_signature_verify": self.enable_signature_verify,
            "max_file_size": self.max_file_size,
            "file_upload_retry_times": self.file_upload_retry_times,
            "file_upload_timeout": self.file_upload_timeout,
            "message_retry_times": self.message_retry_times,
            "enable_markdown_processing": self.enable_markdown_processing,
            "enable_html_reports": self.enable_html_reports,
        }

    def __repr__(self) -> str:
        """字符串表示"""
        config_dict = self.to_dict()
        # 隐藏敏感信息
        if "openrouter_api_key" in config_dict:
            config_dict["openrouter_api_key"] = "***"
        if "rabbitmq_password" in config_dict:
            config_dict["rabbitmq_password"] = "***"
        return f"Config({config_dict})"



"""
CLI build 命令测试

测试 CLI build 命令的各种场景，包括：
- 基础构建命令
- 指定版本参数
- 强制重建参数
- 禁用缓存参数
- 错误处理
- 帮助信息显示
"""

import subprocess
import sys
from pathlib import Path
from typing import List
from unittest.mock import MagicMock, Mock, patch

import pytest

from uni_agent_sdk.build_system.build_manager import BuildManagerError
from uni_agent_sdk.build_system.docker_client import DockerError
from uni_agent_sdk.cli.build import build_command


class TestBuildCommand:
    """测试 build_command 函数"""

    def test_build_command_basic(self, tmp_path: Path, monkeypatch):
        """测试基础构建命令"""
        # 创建测试项目结构
        project_dir = tmp_path / "test-agent"
        project_dir.mkdir()

        # 创建 pyproject.toml
        pyproject_content = """
[project]
name = "test-agent"
version = "1.0.0"
"""
        (project_dir / "pyproject.toml").write_text(pyproject_content)

        # 切换到项目目录
        monkeypatch.chdir(project_dir)

        # Mock Docker 客户端和构建管理器
        with patch("uni_agent_sdk.cli.build.DockerClient") as mock_docker_cls, patch(
            "uni_agent_sdk.cli.build.BuildManager"
        ) as mock_build_mgr_cls:

            # 配置 mock
            mock_docker = MagicMock()
            mock_docker.is_docker_available.return_value = True
            mock_docker_cls.return_value = mock_docker

            mock_build_mgr = MagicMock()
            mock_build_mgr.build_image.return_value = "robot-test-agent:1.0.0"
            mock_build_mgr_cls.return_value = mock_build_mgr

            # 执行命令
            result = build_command()

            # 验证
            assert result is True
            mock_docker.is_docker_available.assert_called_once()
            mock_build_mgr.build_image.assert_called_once_with(
                version=None,
                rebuild=False,
            )

    def test_build_command_with_version(self, tmp_path: Path, monkeypatch):
        """测试指定版本参数"""
        # 创建测试项目
        project_dir = tmp_path / "test-agent"
        project_dir.mkdir()

        pyproject_content = """
[project]
name = "test-agent"
version = "1.0.0"
"""
        (project_dir / "pyproject.toml").write_text(pyproject_content)

        monkeypatch.chdir(project_dir)

        # Mock
        with patch("uni_agent_sdk.cli.build.DockerClient") as mock_docker_cls, patch(
            "uni_agent_sdk.cli.build.BuildManager"
        ) as mock_build_mgr_cls:

            mock_docker = MagicMock()
            mock_docker.is_docker_available.return_value = True
            mock_docker_cls.return_value = mock_docker

            mock_build_mgr = MagicMock()
            mock_build_mgr.build_image.return_value = "robot-test-agent:2.0.0"
            mock_build_mgr_cls.return_value = mock_build_mgr

            # 执行命令，指定版本
            result = build_command(version="2.0.0")

            # 验证
            assert result is True
            mock_build_mgr.build_image.assert_called_once_with(
                version="2.0.0",
                rebuild=False,
            )

    def test_build_command_with_rebuild(self, tmp_path: Path, monkeypatch):
        """测试强制重建参数"""
        project_dir = tmp_path / "test-agent"
        project_dir.mkdir()

        pyproject_content = """
[project]
name = "test-agent"
version = "1.0.0"
"""
        (project_dir / "pyproject.toml").write_text(pyproject_content)

        monkeypatch.chdir(project_dir)

        # Mock
        with patch("uni_agent_sdk.cli.build.DockerClient") as mock_docker_cls, patch(
            "uni_agent_sdk.cli.build.BuildManager"
        ) as mock_build_mgr_cls:

            mock_docker = MagicMock()
            mock_docker.is_docker_available.return_value = True
            mock_docker_cls.return_value = mock_docker

            mock_build_mgr = MagicMock()
            mock_build_mgr.build_image.return_value = "robot-test-agent:1.0.0"
            mock_build_mgr_cls.return_value = mock_build_mgr

            # 执行命令，启用 rebuild
            result = build_command(rebuild=True)

            # 验证
            assert result is True
            mock_build_mgr.build_image.assert_called_once_with(
                version=None,
                rebuild=True,
            )

    def test_build_command_with_no_cache(self, tmp_path: Path, monkeypatch):
        """测试禁用缓存参数"""
        project_dir = tmp_path / "test-agent"
        project_dir.mkdir()

        pyproject_content = """
[project]
name = "test-agent"
version = "1.0.0"
"""
        (project_dir / "pyproject.toml").write_text(pyproject_content)

        monkeypatch.chdir(project_dir)

        # Mock
        with patch("uni_agent_sdk.cli.build.DockerClient") as mock_docker_cls, patch(
            "uni_agent_sdk.cli.build.BuildManager"
        ) as mock_build_mgr_cls:

            mock_docker = MagicMock()
            mock_docker.is_docker_available.return_value = True
            mock_docker_cls.return_value = mock_docker

            mock_build_mgr = MagicMock()
            mock_build_mgr.build_image.return_value = "robot-test-agent:1.0.0"
            mock_build_mgr_cls.return_value = mock_build_mgr

            # 执行命令，启用 no_cache
            result = build_command(no_cache=True)

            # 验证
            assert result is True
            mock_build_mgr.build_image.assert_called_once_with(
                version=None,
                rebuild=True,  # no_cache 应该转换为 rebuild=True
            )

    def test_build_command_no_pyproject(self, tmp_path: Path, monkeypatch):
        """测试缺少 pyproject.toml 的情况"""
        # 创建空目录（没有 pyproject.toml）
        project_dir = tmp_path / "empty-project"
        project_dir.mkdir()

        monkeypatch.chdir(project_dir)

        # 执行命令
        result = build_command()

        # 验证失败
        assert result is False

    def test_build_command_docker_not_available(self, tmp_path: Path, monkeypatch):
        """测试 Docker 不可用的情况"""
        project_dir = tmp_path / "test-agent"
        project_dir.mkdir()

        pyproject_content = """
[project]
name = "test-agent"
version = "1.0.0"
"""
        (project_dir / "pyproject.toml").write_text(pyproject_content)

        monkeypatch.chdir(project_dir)

        # Mock Docker 不可用
        with patch("uni_agent_sdk.cli.build.DockerClient") as mock_docker_cls:
            mock_docker = MagicMock()
            mock_docker.is_docker_available.return_value = False
            mock_docker_cls.return_value = mock_docker

            # 执行命令
            result = build_command()

            # 验证失败
            assert result is False

    def test_build_command_build_manager_error(self, tmp_path: Path, monkeypatch):
        """测试 BuildManager 抛出异常的情况"""
        project_dir = tmp_path / "test-agent"
        project_dir.mkdir()

        pyproject_content = """
[project]
name = "test-agent"
version = "1.0.0"
"""
        (project_dir / "pyproject.toml").write_text(pyproject_content)

        monkeypatch.chdir(project_dir)

        # Mock
        with patch("uni_agent_sdk.cli.build.DockerClient") as mock_docker_cls, patch(
            "uni_agent_sdk.cli.build.BuildManager"
        ) as mock_build_mgr_cls:

            mock_docker = MagicMock()
            mock_docker.is_docker_available.return_value = True
            mock_docker_cls.return_value = mock_docker

            mock_build_mgr = MagicMock()
            mock_build_mgr.build_image.side_effect = BuildManagerError("构建失败")
            mock_build_mgr_cls.return_value = mock_build_mgr

            # 执行命令
            result = build_command()

            # 验证失败
            assert result is False

    def test_build_command_docker_error(self, tmp_path: Path, monkeypatch):
        """测试 Docker 操作失败的情况"""
        project_dir = tmp_path / "test-agent"
        project_dir.mkdir()

        pyproject_content = """
[project]
name = "test-agent"
version = "1.0.0"
"""
        (project_dir / "pyproject.toml").write_text(pyproject_content)

        monkeypatch.chdir(project_dir)

        # Mock
        with patch("uni_agent_sdk.cli.build.DockerClient") as mock_docker_cls, patch(
            "uni_agent_sdk.cli.build.BuildManager"
        ) as mock_build_mgr_cls:

            mock_docker = MagicMock()
            mock_docker.is_docker_available.return_value = True
            mock_docker_cls.return_value = mock_docker

            mock_build_mgr = MagicMock()
            mock_build_mgr.build_image.side_effect = DockerError("Docker 构建失败")
            mock_build_mgr_cls.return_value = mock_build_mgr

            # 执行命令
            result = build_command()

            # 验证失败
            assert result is False

    def test_build_command_keyboard_interrupt(self, tmp_path: Path, monkeypatch):
        """测试用户中断的情况"""
        project_dir = tmp_path / "test-agent"
        project_dir.mkdir()

        pyproject_content = """
[project]
name = "test-agent"
version = "1.0.0"
"""
        (project_dir / "pyproject.toml").write_text(pyproject_content)

        monkeypatch.chdir(project_dir)

        # Mock
        with patch("uni_agent_sdk.cli.build.DockerClient") as mock_docker_cls, patch(
            "uni_agent_sdk.cli.build.BuildManager"
        ) as mock_build_mgr_cls:

            mock_docker = MagicMock()
            mock_docker.is_docker_available.return_value = True
            mock_docker_cls.return_value = mock_docker

            mock_build_mgr = MagicMock()
            mock_build_mgr.build_image.side_effect = KeyboardInterrupt()
            mock_build_mgr_cls.return_value = mock_build_mgr

            # 执行命令
            result = build_command()

            # 验证失败
            assert result is False


class TestBuildCommandCLI:
    """测试 CLI 集成"""

    def test_cli_help(self):
        """测试帮助信息显示"""
        result = subprocess.run(
            [sys.executable, "-m", "uni_agent_sdk.cli", "build", "--help"],
            capture_output=True,
            text=True,
        )

        # 验证帮助信息包含关键内容
        assert result.returncode == 0
        assert "构建智能体 Docker 镜像" in result.stdout
        assert "--version" in result.stdout
        assert "--rebuild" in result.stdout
        assert "--no-cache" in result.stdout

    def test_cli_version_option(self):
        """测试版本选项存在"""
        result = subprocess.run(
            [sys.executable, "-m", "uni_agent_sdk.cli", "build", "--help"],
            capture_output=True,
            text=True,
        )

        # 验证 --version 选项存在
        assert "--version" in result.stdout or "-v" in result.stdout

    def test_cli_rebuild_option(self):
        """测试 rebuild 选项存在"""
        result = subprocess.run(
            [sys.executable, "-m", "uni_agent_sdk.cli", "build", "--help"],
            capture_output=True,
            text=True,
        )

        # 验证 --rebuild 选项存在
        assert "--rebuild" in result.stdout

    def test_cli_no_cache_option(self):
        """测试 no-cache 选项存在"""
        result = subprocess.run(
            [sys.executable, "-m", "uni_agent_sdk.cli", "build", "--help"],
            capture_output=True,
            text=True,
        )

        # 验证 --no-cache 选项存在
        assert "--no-cache" in result.stdout


class TestBuildCommandEdgeCases:
    """测试边缘情况"""

    def test_build_with_both_rebuild_and_no_cache(self, tmp_path: Path, monkeypatch):
        """测试同时指定 rebuild 和 no_cache 的情况"""
        project_dir = tmp_path / "test-agent"
        project_dir.mkdir()

        pyproject_content = """
[project]
name = "test-agent"
version = "1.0.0"
"""
        (project_dir / "pyproject.toml").write_text(pyproject_content)

        monkeypatch.chdir(project_dir)

        # Mock
        with patch("uni_agent_sdk.cli.build.DockerClient") as mock_docker_cls, patch(
            "uni_agent_sdk.cli.build.BuildManager"
        ) as mock_build_mgr_cls:

            mock_docker = MagicMock()
            mock_docker.is_docker_available.return_value = True
            mock_docker_cls.return_value = mock_docker

            mock_build_mgr = MagicMock()
            mock_build_mgr.build_image.return_value = "robot-test-agent:1.0.0"
            mock_build_mgr_cls.return_value = mock_build_mgr

            # 执行命令，同时启用两个参数
            result = build_command(rebuild=True, no_cache=True)

            # 验证
            assert result is True
            mock_build_mgr.build_image.assert_called_once_with(
                version=None,
                rebuild=True,  # 应该使用 True
            )

    def test_build_with_all_options(self, tmp_path: Path, monkeypatch):
        """测试指定所有选项的情况"""
        project_dir = tmp_path / "test-agent"
        project_dir.mkdir()

        pyproject_content = """
[project]
name = "test-agent"
version = "1.0.0"
"""
        (project_dir / "pyproject.toml").write_text(pyproject_content)

        monkeypatch.chdir(project_dir)

        # Mock
        with patch("uni_agent_sdk.cli.build.DockerClient") as mock_docker_cls, patch(
            "uni_agent_sdk.cli.build.BuildManager"
        ) as mock_build_mgr_cls:

            mock_docker = MagicMock()
            mock_docker.is_docker_available.return_value = True
            mock_docker_cls.return_value = mock_docker

            mock_build_mgr = MagicMock()
            mock_build_mgr.build_image.return_value = "robot-test-agent:3.0.0"
            mock_build_mgr_cls.return_value = mock_build_mgr

            # 执行命令，指定所有选项
            result = build_command(
                version="3.0.0",
                rebuild=True,
                config="custom.toml",
                tag="custom-tag",
                no_cache=True,
            )

            # 验证
            assert result is True
            mock_build_mgr.build_image.assert_called_once_with(
                version="3.0.0",
                rebuild=True,
            )

    def test_build_with_generic_exception(self, tmp_path: Path, monkeypatch):
        """测试未知异常的情况"""
        project_dir = tmp_path / "test-agent"
        project_dir.mkdir()

        pyproject_content = """
[project]
name = "test-agent"
version = "1.0.0"
"""
        (project_dir / "pyproject.toml").write_text(pyproject_content)

        monkeypatch.chdir(project_dir)

        # Mock
        with patch("uni_agent_sdk.cli.build.DockerClient") as mock_docker_cls, patch(
            "uni_agent_sdk.cli.build.BuildManager"
        ) as mock_build_mgr_cls:

            mock_docker = MagicMock()
            mock_docker.is_docker_available.return_value = True
            mock_docker_cls.return_value = mock_docker

            mock_build_mgr = MagicMock()
            mock_build_mgr.build_image.side_effect = RuntimeError("未知错误")
            mock_build_mgr_cls.return_value = mock_build_mgr

            # 执行命令
            result = build_command()

            # 验证失败
            assert result is False



import os
from setuptools import setup, find_packages

setup(
    name="uni_agent_sdk",
    version="0.2.0",
    description="极简的uni-im平台智能体开发框架",
    long_description=open("README.md", encoding="utf-8").read() if os.path.exists("README.md") else "",
    long_description_content_type="text/markdown",
    author="uni-im",
    author_email="support@uni-im.com",
    url="https://github.com/uni-im/uni-agent-sdk",
    packages=find_packages(),
    include_package_data=True,
    python_requires=">=3.8",
    install_requires=[
        "aiohttp>=3.8.0",
        "pydantic>=1.10.0",
        "litellm>=1.0.0",
        "pika>=1.3.0",
    ],
    extras_require={
        "dev": [
            "pytest>=7.0.0",
            "pytest-asyncio>=0.21.0",
            "black>=22.0.0",
            "isort>=5.10.0",
            "flake8>=4.0.0",
            "mypy>=0.991",
        ],
        "docs": [
            "sphinx>=5.0.0",
            "sphinx-rtd-theme>=1.0.0",
        ],
    },
    entry_points={
        "console_scripts": [
            "uni-agent=uni_agent_sdk.cli:main",
        ],
    },
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Communications :: Chat",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
    ],
    keywords=["chatbot", "agent", "ai", "uni-im", "messaging"],
    license="MIT",
    zip_safe=False,
)


"""
环境变量加载功能的单元测试

测试场景：
1. 从 .env 文件加载环境变量
2. 处理缺失的文件
3. 处理格式错误的行
4. 处理注释和空行
5. 支持引号值
"""

import tempfile
from pathlib import Path

import pytest

from uni_agent_sdk.build_system.run_manager import RunManager
from uni_agent_sdk.build_system.publish_manager import PublishManager


class TestEnvFileLoading:
    """环境变量文件加载测试（直接测试）"""

    def test_parse_env_file_success(self):
        """测试成功解析 .env 文件"""
        # 直接测试解析逻辑（无需 RunManager）
        with tempfile.TemporaryDirectory() as tmpdir:
            env_file = Path(tmpdir) / ".env"
            env_file.write_text(
                """# 本地开发配置
DEBUG=true
LOG_LEVEL=DEBUG
API_KEY=test-key-12345
DATABASE_URL=postgres://localhost:5432/test
"""
            )

            # 手动解析
            env_vars = {}
            with open(env_file, encoding="utf-8") as f:
                for line in f:
                    line = line.strip()
                    if not line or line.startswith("#"):
                        continue
                    if "=" not in line:
                        continue
                    key, value = line.split("=", 1)
                    key = key.strip()
                    value = value.strip()
                    if value and value[0] in ('"', "'") and value[-1] == value[0]:
                        value = value[1:-1]
                    env_vars[key] = value

            # 验证结果
            assert len(env_vars) == 4
            assert env_vars["DEBUG"] == "true"
            assert env_vars["LOG_LEVEL"] == "DEBUG"
            assert env_vars["API_KEY"] == "test-key-12345"
            assert env_vars["DATABASE_URL"] == "postgres://localhost:5432/test"

    def test_parse_env_file_with_quotes(self):
        """测试加载带有引号的值"""
        with tempfile.TemporaryDirectory() as tmpdir:
            env_file = Path(tmpdir) / ".env"
            env_file.write_text(
                """VALUE1="value with spaces"
VALUE2='single quoted'
VALUE3=no-quotes
"""
            )

            env_vars = {}
            with open(env_file, encoding="utf-8") as f:
                for line in f:
                    line = line.strip()
                    if not line or line.startswith("#"):
                        continue
                    if "=" not in line:
                        continue
                    key, value = line.split("=", 1)
                    key = key.strip()
                    value = value.strip()
                    if value and value[0] in ('"', "'") and value[-1] == value[0]:
                        value = value[1:-1]
                    env_vars[key] = value

            assert env_vars["VALUE1"] == "value with spaces"
            assert env_vars["VALUE2"] == "single quoted"
            assert env_vars["VALUE3"] == "no-quotes"

    def test_parse_env_file_with_equals_in_value(self):
        """测试值中包含等号的情况"""
        with tempfile.TemporaryDirectory() as tmpdir:
            env_file = Path(tmpdir) / ".env"
            env_file.write_text("DATABASE_URL=postgres://user:pass@localhost:5432/db?sslmode=require\n")

            env_vars = {}
            with open(env_file, encoding="utf-8") as f:
                for line in f:
                    line = line.strip()
                    if not line or line.startswith("#"):
                        continue
                    if "=" not in line:
                        continue
                    key, value = line.split("=", 1)
                    key = key.strip()
                    value = value.strip()
                    if value and value[0] in ('"', "'") and value[-1] == value[0]:
                        value = value[1:-1]
                    env_vars[key] = value

            assert env_vars["DATABASE_URL"] == "postgres://user:pass@localhost:5432/db?sslmode=require"

    def test_parse_env_file_ignores_comments_and_empty_lines(self):
        """测试忽略注释和空行"""
        with tempfile.TemporaryDirectory() as tmpdir:
            env_file = Path(tmpdir) / ".env"
            env_file.write_text(
                """# 这是注释
KEY1=value1

# 另一个注释
KEY2=value2


KEY3=value3
"""
            )

            env_vars = {}
            with open(env_file, encoding="utf-8") as f:
                for line in f:
                    line = line.strip()
                    if not line or line.startswith("#"):
                        continue
                    if "=" not in line:
                        continue
                    key, value = line.split("=", 1)
                    key = key.strip()
                    value = value.strip()
                    if value and value[0] in ('"', "'") and value[-1] == value[0]:
                        value = value[1:-1]
                    env_vars[key] = value

            assert len(env_vars) == 3
            assert "KEY1" in env_vars
            assert "KEY2" in env_vars
            assert "KEY3" in env_vars

    def test_parse_env_file_ignores_invalid_lines(self):
        """测试忽略格式错误的行"""
        with tempfile.TemporaryDirectory() as tmpdir:
            env_file = Path(tmpdir) / ".env"
            env_file.write_text(
                """KEY1=value1
INVALID_LINE_WITHOUT_EQUALS
KEY2=value2
"""
            )

            env_vars = {}
            with open(env_file, encoding="utf-8") as f:
                for line in f:
                    line = line.strip()
                    if not line or line.startswith("#"):
                        continue
                    if "=" not in line:
                        continue
                    key, value = line.split("=", 1)
                    key = key.strip()
                    value = value.strip()
                    if value and value[0] in ('"', "'") and value[-1] == value[0]:
                        value = value[1:-1]
                    env_vars[key] = value

            # 应该跳过没有等号的行
            assert len(env_vars) == 2
            assert env_vars["KEY1"] == "value1"
            assert env_vars["KEY2"] == "value2"


class TestPublishManagerEnvLoading:
    """PublishManager 环境变量加载测试"""

    @pytest.fixture
    def temp_project_dir(self):
        """创建临时项目目录"""
        with tempfile.TemporaryDirectory() as tmpdir:
            yield Path(tmpdir)

    def test_load_environment_variables_success(self, temp_project_dir):
        """测试成功加载环境变量"""
        # 创建 .env 文件
        env_file = temp_project_dir / ".env"
        env_file.write_text(
            """ROBOT_APPKEY=test-robot
DEBUG=true
LOG_LEVEL=DEBUG
"""
        )

        # 创建 PublishManager（使用 Mock）
        from unittest.mock import MagicMock

        publish_manager = PublishManager(
            config_provider=MagicMock(),
            cloud_client=MagicMock(),
            build_manager=MagicMock(),
            docker_client=MagicMock(),
        )

        env_vars = publish_manager.load_environment_variables(str(env_file))

        assert len(env_vars) == 3
        assert env_vars["ROBOT_APPKEY"] == "test-robot"
        assert env_vars["DEBUG"] == "true"

    def test_load_environment_variables_production(self, temp_project_dir):
        """测试加载生产环境配置"""
        # 创建 .env.prod 文件
        env_file = temp_project_dir / ".env.prod"
        env_file.write_text(
            """ROBOT_APPKEY=prod-robot-main
DEBUG=false
LOG_LEVEL=INFO
DATABASE_URL=postgres://prod-db.example.com:5432/prod
API_KEY=prod-key-abcde12345xyz
"""
        )

        from unittest.mock import MagicMock

        publish_manager = PublishManager(
            config_provider=MagicMock(),
            cloud_client=MagicMock(),
            build_manager=MagicMock(),
            docker_client=MagicMock(),
        )

        env_vars = publish_manager.load_environment_variables(str(env_file))

        assert len(env_vars) == 5
        assert env_vars["ROBOT_APPKEY"] == "prod-robot-main"
        assert env_vars["DEBUG"] == "false"
        assert env_vars["LOG_LEVEL"] == "INFO"
        assert "DATABASE_URL" in env_vars
        assert "API_KEY" in env_vars

    def test_load_environment_variables_missing(self, temp_project_dir):
        """测试文件不存在的情况"""
        from unittest.mock import MagicMock

        publish_manager = PublishManager(
            config_provider=MagicMock(),
            cloud_client=MagicMock(),
            build_manager=MagicMock(),
            docker_client=MagicMock(),
        )

        env_vars = publish_manager.load_environment_variables(
            str(temp_project_dir / ".env.missing")
        )

        assert env_vars == {}

    def test_load_environment_variables_with_default(self, temp_project_dir):
        """测试使用默认 .env 文件"""
        env_file = temp_project_dir / ".env"
        env_file.write_text("KEY1=value1\n")

        from unittest.mock import MagicMock

        # 改变当前工作目录
        import os

        old_cwd = os.getcwd()
        try:
            os.chdir(temp_project_dir)
            publish_manager = PublishManager(
                config_provider=MagicMock(),
                cloud_client=MagicMock(),
                build_manager=MagicMock(),
                docker_client=MagicMock(),
            )

            # 不指定文件路径，使用默认 .env
            env_vars = publish_manager.load_environment_variables()

            assert "KEY1" in env_vars
            assert env_vars["KEY1"] == "value1"
        finally:
            os.chdir(old_cwd)



"""Build system module for robot Docker image building and publishing."""

from .build_manager import BuildManager, BuildManagerError
from .cloud_function_client import (
    AuthenticationError,
    CloudFunctionClient,
    CloudFunctionError,
    ConfigurationError,
    NetworkError,
)
from .config_provider import ConfigProvider
from .docker_client import DockerClient, DockerError
from .dockerfile_generator import DockerfileGenerator
from .publish_manager import PublishManager, PublishManagerError

__all__ = [
    "BuildManager",
    "BuildManagerError",
    "ConfigProvider",
    "CloudFunctionClient",
    "CloudFunctionError",
    "AuthenticationError",
    "NetworkError",
    "ConfigurationError",
    "DockerClient",
    "DockerError",
    "DockerfileGenerator",
    "PublishManager",
    "PublishManagerError",
]



#!/usr/bin/env python3
"""OSS功能独立测试脚本

专门测试HTML文件上传到OSS的功能，不依赖平台认证。
"""

import sys
import os
import asyncio
from datetime import datetime

# 添加SDK路径
sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.abspath(__file__))))

from uni_agent_sdk.services.file import FileService
from uni_agent_sdk.utils.config import Config
from uni_agent_sdk import setup_agent_logging

async def test_oss_functionality():
    """测试OSS核心功能"""

    print("🧪 开始OSS功能独立测试...")

    # 初始化配置
    config = Config()

    # 创建文件服务
    file_service = FileService(config)

    try:
        # 创建测试HTML内容
        html_content = create_test_html()
        print(f"📝 生成测试HTML内容 ({len(html_content)} 字符)")

        # 测试HTML上传到OSS
        print("🔄 开始上传HTML到OSS...")
        result = await file_service.upload_html_to_oss(
            html_content=html_content,
            filename="oss_test_report.html"
        )

        if result.get('success'):
            print(f"✅ OSS上传成功！")
            print(f"📄 文件URL: {result.get('file_url')}")
            print(f"📊 文件大小: {result.get('size')} 字节")
            print(f"🕒 上传时间: {result.get('upload_time')}")

            # 验证文件是否可访问
            print("🔍 验证文件可访问性...")
            file_info = await file_service.get_file_info(result['file_url'])
            print(f"✅ 文件验证成功: {file_info.get('content_type')}")

        else:
            print(f"❌ OSS上传失败: {result.get('error')}")

    except Exception as e:
        print(f"❌ 测试过程中出错: {e}")
    finally:
        # 清理资源
        await file_service.close()

def create_test_html():
    """创建测试HTML内容"""
    current_time = datetime.now().strftime('%Y-%m-%d %H:%M:%S')

    return f"""<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>OSS功能测试报告</title>
    <style>
        body {{
            font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', sans-serif;
            line-height: 1.6;
            color: #333;
            max-width: 800px;
            margin: 0 auto;
            padding: 20px;
            background: #f8f9fa;
        }}
        .header {{
            background: linear-gradient(135deg, #28a745 0%, #20c997 100%);
            color: white;
            padding: 30px;
            border-radius: 10px;
            text-align: center;
            margin-bottom: 30px;
        }}
        .card {{
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0,0,0,0.1);
            margin-bottom: 20px;
        }}
        .success {{
            color: #28a745;
            font-weight: bold;
        }}
        .info {{
            display: flex;
            justify-content: space-between;
            padding: 10px 0;
            border-bottom: 1px solid #eee;
        }}
        .info:last-child {{
            border-bottom: none;
        }}
        .value {{
            font-weight: bold;
            color: #007fff;
        }}
    </style>
</head>
<body>
    <div class="header">
        <h1>🎯 OSS功能测试报告</h1>
        <p>uni-agent-sdk OSS集成测试结果</p>
    </div>

    <div class="card">
        <h3>📊 测试结果</h3>
        <div class="info">
            <span>OSS上传功能</span>
            <span class="success">✅ 正常</span>
        </div>
        <div class="info">
            <span>HTML预览功能</span>
            <span class="success">✅ 可用</span>
        </div>
        <div class="info">
            <span>Content-Disposition</span>
            <span class="success">✅ inline模式</span>
        </div>
        <div class="info">
            <span>测试时间</span>
            <span class="value">{current_time}</span>
        </div>
    </div>

    <div class="card">
        <h3>🔧 技术验证</h3>
        <ul>
            <li>✅ 阿里云OSS集成正常</li>
            <li>✅ HTML文件上传成功</li>
            <li>✅ 浏览器预览支持</li>
            <li>✅ 文件URL生成正确</li>
            <li>✅ Content-Type设置正确</li>
        </ul>
    </div>

    <div class="card">
        <h3>📝 总结</h3>
        <p>OSS集成功能测试全部通过，系统工作正常。此HTML文件成功上传到阿里云OSS，
        并可通过浏览器直接预览而非下载，验证了核心功能的完整性。</p>
    </div>

    <div style="text-align: center; color: #666; font-size: 14px; margin-top: 30px;">
        <p>🎉 测试完成时间: {current_time}</p>
    </div>
</body>
</html>"""

if __name__ == "__main__":
    # 设置日志
    setup_agent_logging()

    print("🚀 启动OSS功能独立测试")
    asyncio.run(test_oss_functionality())
    print("🏁 测试完成")


#!/usr/bin/env python3
"""Kimi API测试脚本

测试Kimi API配置是否正确工作
"""

import asyncio
import os

from openai import AsyncOpenAI


async def test_kimi_api():
    """测试Kimi API"""
    print("🧪 测试Kimi API配置...")
    print("=" * 50)

    # Kimi API配置
    api_key = "sk-WBOFCIXf0D3k2Bj9JjT41S99F4hMcd4G4zCMtqbyPkkZqT1R"
    base_url = "https://api.moonshot.cn/v1"
    model = "kimi-k2-turbo-preview"

    print(f"📋 API配置:")
    print(f"   模型: {model}")
    print(f"   API Base: {base_url}")
    print(f"   API Key: {api_key[:20]}...")
    print()

    try:
        # 创建客户端
        client = AsyncOpenAI(api_key=api_key, base_url=base_url)

        print("🔤 发送测试消息...")

        # 测试消息
        completion = await client.chat.completions.create(
            model=model,
            messages=[
                {
                    "role": "system",
                    "content": "你是 Kimi，由 Moonshot AI 提供的人工智能助手，你更擅长中文和英文的对话。你会为用户提供安全，有帮助，准确的回答。同时，你会拒绝一切涉及恐怖主义，种族歧视，黄色暴力等问题的回答。Moonshot AI 为专有名词，不可翻译成其他语言。",
                },
                {"role": "user", "content": "你好，我叫李雷，1+1等于多少？"},
            ],
            temperature=0.6,
        )

        response_content = completion.choices[0].message.content

        print("✅ Kimi API测试成功!")
        print("📤 AI回复:")
        print(f"   {response_content}")
        print()
        print("🎉 Kimi API配置正确，可以正常使用!")

        return True

    except Exception as e:
        print(f"❌ Kimi API测试失败: {e}")
        return False

    finally:
        await client.close()


async def main():
    """主函数"""
    print("🚀 Kimi API配置测试")
    print("=" * 50)

    success = await test_kimi_api()

    print("=" * 50)
    if success:
        print("🎊 测试结果: Kimi API配置成功!")
        print("✅ 现在可以使用Kimi进行智能对话")
    else:
        print("💥 测试结果: Kimi API配置失败")
        print("❌ 请检查API密钥和网络连接")
    print("=" * 50)


if __name__ == "__main__":
    asyncio.run(main())



"""
端到端集成测试 - Robot Build & Publish 系统

验证完整的 build → publish → deploy 工作流程
"""

import subprocess
import sys
from pathlib import Path
from unittest.mock import AsyncMock, MagicMock, patch

import pytest


class TestE2EBuildPublishWorkflow:
    """端到端完整工作流测试"""

    def test_full_build_and_publish_workflow(self, monkeypatch):
        """测试完整的 build → publish 工作流

        场景：
        1. 执行 build 命令构建镜像
        2. 验证镜像成功构建
        3. 执行 publish 命令发布镜像
        4. 验证发布成功
        """
        # 定位 oss-agent 项目
        project_root = Path(__file__).parent.parent.parent
        oss_agent_dir = project_root / "robots" / "oss-agent"

        if not oss_agent_dir.exists():
            pytest.skip("oss-agent 项目不存在，跳过 E2E 测试")

        monkeypatch.chdir(oss_agent_dir)

        # Mock 外部服务
        with patch("uni_agent_sdk.cli.build.DockerClient") as mock_docker_cls, patch(
            "uni_agent_sdk.cli.build.BuildManager"
        ) as mock_build_mgr_cls, patch(
            "uni_agent_sdk.cli.publish.ConfigProvider"
        ) as mock_config_cls, patch(
            "uni_agent_sdk.cli.publish.CloudFunctionClient"
        ) as mock_cloud_cls, patch(
            "uni_agent_sdk.cli.publish.PublishManager"
        ) as mock_publish_mgr_cls:

            # 配置 build 命令的 mock
            mock_docker = MagicMock()
            mock_docker.is_docker_available.return_value = True
            mock_docker_cls.return_value = mock_docker

            mock_build_mgr = MagicMock()
            mock_build_mgr.project_config = {
                "name": "oss-agent",
                "version": "1.0.0",
                "package_name": "oss_agent",
            }
            mock_build_mgr.build_image.return_value = "robot-oss-agent:1.0.0"
            mock_build_mgr.get_image_info.return_value = {
                "tag": "robot-oss-agent:1.0.0",
                "image_id": "sha256:abc123",
                "size": 350,
                "build_time": 45.5,
            }
            mock_build_mgr_cls.return_value = mock_build_mgr

            # 配置 publish 命令的 mock
            mock_config = MagicMock()
            mock_config.get_robot_appkey.return_value = "test-appkey"
            mock_config_cls.return_value = mock_config

            mock_cloud_client = MagicMock()
            mock_cloud_cls.return_value = mock_cloud_client

            mock_publish_mgr = MagicMock()
            mock_publish_mgr.publish = AsyncMock(
                return_value={
                    "success": True,
                    "image_url": "registry.example.com/robots/oss-agent:1.0.0",
                    "robot_id": "robot-oss-agent-001",
                    "deployment_status": "deploying",
                }
            )
            mock_publish_mgr_cls.return_value = mock_publish_mgr

            # 步骤 1: 执行 build 命令
            from uni_agent_sdk.cli.build import build_command

            build_result = build_command()
            assert build_result is True
            mock_build_mgr.build_image.assert_called_once()

            # 步骤 2: 验证镜像信息
            image_info = mock_build_mgr.get_image_info("robot-oss-agent:1.0.0")
            assert image_info["tag"] == "robot-oss-agent:1.0.0"
            assert image_info["size"] > 0

            # 步骤 3: 执行 publish 命令
            from uni_agent_sdk.cli.publish import publish_command

            publish_result = publish_command(skip_build=True)
            assert publish_result is True
            mock_publish_mgr.publish.assert_called_once()

    def test_cli_help_shows_all_commands(self):
        """测试 CLI help 显示所有命令"""
        result = subprocess.run(
            [sys.executable, "-m", "uni_agent_sdk.cli", "--help"],
            capture_output=True,
            text=True,
        )

        assert result.returncode == 0
        assert "build" in result.stdout
        assert "publish" in result.stdout

    def test_build_command_help(self):
        """测试 build 命令的帮助信息"""
        result = subprocess.run(
            [sys.executable, "-m", "uni_agent_sdk.cli", "build", "--help"],
            capture_output=True,
            text=True,
        )

        assert result.returncode == 0
        assert "--version" in result.stdout

    def test_publish_command_help(self):
        """测试 publish 命令的帮助信息"""
        result = subprocess.run(
            [sys.executable, "-m", "uni_agent_sdk.cli", "publish", "--help"],
            capture_output=True,
            text=True,
        )

        assert result.returncode == 0
        assert "--skip-build" in result.stdout


class TestE2EErrorHandling:
    """端到端错误处理测试"""

    def test_build_fails_when_docker_unavailable(self, monkeypatch):
        """测试 Docker 不可用时 build 命令的错误处理"""
        project_root = Path(__file__).parent.parent.parent
        oss_agent_dir = project_root / "robots" / "oss-agent"

        if not oss_agent_dir.exists():
            pytest.skip("oss-agent 项目不存在，跳过 E2E 测试")

        monkeypatch.chdir(oss_agent_dir)

        with patch("uni_agent_sdk.cli.build.DockerClient") as mock_docker_cls, patch(
            "uni_agent_sdk.cli.build.BuildManager"
        ) as mock_build_mgr_cls:

            mock_docker = MagicMock()
            mock_docker.is_docker_available.return_value = False
            mock_docker_cls.return_value = mock_docker

            from uni_agent_sdk.cli.build import build_command

            # 当 Docker 不可用时应该返回 False
            result = build_command()
            assert result is False

    def test_build_fails_on_missing_pyproject(self, monkeypatch):
        """测试缺少 pyproject.toml 时 build 命令的错误处理"""
        import tempfile

        with tempfile.TemporaryDirectory() as tmp_dir:
            monkeypatch.chdir(tmp_dir)

            from uni_agent_sdk.cli.build import build_command

            # 应该失败，因为没有 pyproject.toml
            result = build_command()
            assert result is False


class TestE2EIntegration:
    """端到端集成测试"""

    def test_build_manager_reads_real_project_config(self):
        """测试 BuildManager 能正确读取真实项目配置"""
        project_root = Path(__file__).parent.parent.parent
        oss_agent_dir = project_root / "robots" / "oss-agent"

        if not oss_agent_dir.exists():
            pytest.skip("oss-agent 项目不存在，跳过 E2E 测试")

        from uni_agent_sdk.build_system.build_manager import BuildManager
        from uni_agent_sdk.build_system.docker_client import DockerClient

        docker_client = DockerClient(verbose=False)
        build_manager = BuildManager(oss_agent_dir, docker_client)

        # 验证配置读取
        config = build_manager.project_config
        assert config["name"] == "oss-agent"
        assert config["version"] == "1.0.0"
        assert config["package_name"] == "oss_agent"

    def test_docker_client_availability_check(self):
        """测试 DockerClient 的 Docker 可用性检查"""
        from uni_agent_sdk.build_system.docker_client import DockerClient

        docker_client = DockerClient(verbose=False)
        is_available = docker_client.is_docker_available()
        assert isinstance(is_available, bool)

    def test_config_provider_loads_env_variables(self, monkeypatch):
        """测试 ConfigProvider 能加载环境变量"""
        monkeypatch.setenv("ROBOT_APPKEY", "test-appkey-123")
        monkeypatch.setenv("CLOUD_FUNCTION_URL", "https://test.example.com/api")

        from uni_agent_sdk.build_system.config_provider import ConfigProvider

        config = ConfigProvider()

        # 验证读取
        assert config.get_robot_appkey() == "test-appkey-123"
        assert config.get_cloud_function_url() == "https://test.example.com/api"

    def test_dockerfile_generator_creates_valid_dockerfile(self):
        """测试 DockerfileGenerator 能生成有效的 Dockerfile"""
        import tempfile

        from uni_agent_sdk.build_system.dockerfile_generator import DockerfileGenerator

        with tempfile.TemporaryDirectory() as tmp_dir:
            project_dir = Path(tmp_dir)

            # 生成 Dockerfile
            generator = DockerfileGenerator()
            dockerfile_path = generator.generate(project_dir, "test_package")

            # 验证文件存在
            assert dockerfile_path.exists()

            # 验证内容有效
            content = dockerfile_path.read_text()
            assert "FROM python" in content
            assert "test_package" in content



"""平台API通信服务"""

import asyncio
import json
import logging
from typing import Any, Dict, Optional

import aiohttp

from ..models.message import Response
from ..utils.config import Config
from ..utils.crypto import sign_data


class PlatformAPI:
    """平台API通信服务类

    处理与uni-im平台的所有HTTP通信，包括：
    - 智能体信息获取
    - 会话上下文获取
    - 响应消息发送
    """

    def __init__(self, api_key: str, api_secret: str, config: Config):
        """初始化平台API服务

        Args:
            api_key: 智能体API密钥
            api_secret: 智能体API秘钥
            config: 配置对象
        """
        self.api_key = api_key
        self.api_secret = api_secret
        self.config = config
        self.base_url = config.platform_base_url

        self.logger = logging.getLogger(f"PlatformAPI-{api_key[:8]}")

        # 认证信息（通过set_auth_info设置）
        self._developer_userid: Optional[str] = None
        self._jwt_token: Optional[str] = None

        # HTTP会话配置
        self._session: Optional[aiohttp.ClientSession] = None

    def set_auth_info(self, developer_userid: str, jwt_token: str):
        """设置认证信息

        Args:
            developer_userid: 开发者用户ID
            jwt_token: JWT访问令牌
        """
        self._developer_userid = developer_userid
        self._jwt_token = jwt_token
        self.logger.info(
            f"🔄 设置认证信息: developer_userid={developer_userid}, token={jwt_token[:20]}..."
        )

        # 强制重置会话，确保下次使用时创建新会话
        if self._session:
            try:
                if not self._session.closed:
                    # 异步关闭现有会话
                    asyncio.create_task(self._session.close())
                    self.logger.info("🗑️ 已关闭旧HTTP会话")
            except Exception as e:
                self.logger.warning(f"关闭旧会话时出错: {e}")

        # 无论如何都重置会话引用
        self._session = None
        self.logger.info("✅ 认证信息已设置，HTTP会话已重置")

    async def _get_session(self) -> aiohttp.ClientSession:
        """获取HTTP会话（懒加载）"""
        if self._session is None or self._session.closed:
            timeout = aiohttp.ClientTimeout(
                total=self.config.http_timeout, connect=self.config.http_connect_timeout
            )

            headers = {
                "Content-Type": "application/json",
                "User-Agent": "uni-agent-sdk/1.0",
            }

            # 添加 CONNECTCODE 头部用于 S2S 认证
            if self.config.connectcode:
                headers["Unicloud-S2s-Authorization"] = (
                    f"CONNECTCODE {self.config.connectcode}"
                )

            # 添加机器人用户身份信息（如果已获取认证信息）
            if self._jwt_token and self._developer_userid:
                headers["uni-id-token"] = self._jwt_token
                headers["uni-id-uid"] = self._developer_userid
                self.logger.info(
                    f"✅ 使用JWT认证: uid={self._developer_userid}, token={self._jwt_token[:20]}..."
                )
            else:
                # 未认证状态，仅用于注册
                headers["uni-id-token"] = ""
                headers["uni-id-uid"] = ""
                # self.logger.warning("⚠️ 使用S2S认证（注册模式）- 可能导致API调用失败")

            self.logger.debug(f"HTTP Headers: {headers}")

            self._session = aiohttp.ClientSession(timeout=timeout, headers=headers)
        return self._session

    async def close(self):
        """关闭HTTP会话"""
        if self._session and not self._session.closed:
            await self._session.close()

    async def register_robot(self) -> Dict[str, Any]:
        """注册机器人并获取完整认证信息

        这是认证流程的第一步，使用api_key/api_secret进行机器人注册，
        平台会返回：developer_userid, JWT令牌, RabbitMQ配置, 文件服务配置等完整认证信息

        Returns:
            包含完整认证信息的字典，格式：
            {
                "errCode": 0,
                "data": {
                    "robot_id": "智能体ID",
                    "developer_userid": "开发者用户ID",
                    "token": "JWT访问令牌",
                    "expires_at": JWT令牌过期时间戳,
                    "rabbitmq_config": {
                        "host": "RabbitMQ主机",
                        "port": 端口,
                        "vhost": "虚拟主机",
                        "username": "用户名",
                        "auth_mechanism": "JWT",
                        "queue_name": "RabbitMQ队列名"
                    },
                    "file_service_config": {
                        "access_key_id": "OSS访问密钥ID",
                        "access_key_secret": "OSS访问密钥",
                        "bucket_name": "OSS桶名称",
                        "endpoint": "OSS端点",
                        "region": "服务区域",
                        "base_path": "基础路径",
                        "expires_at": OSS密钥过期时间戳
                    }
                }
            }
        """
        data = {"api_key": self.api_key, "api_secret": self.api_secret}

        try:
            session = await self._get_session()
            url = f"{self.base_url}/uni-im-co/registerRobot"  # 注册端点

            self.logger.debug(f"注册机器人: {url}")
            self.logger.debug(f"请求数据: {data}")

            async with session.post(url, json=data) as resp:
                if resp.status != 200:
                    raise Exception(f"HTTP请求失败: {resp.status}")

                result = await resp.json()
                self.logger.debug(f"机器人注册响应: {result}")

                if result.get("errCode") != 0:
                    raise Exception(
                        f"机器人注册失败: {result.get('errMsg', '未知错误')}"
                    )

                return result

        except Exception as e:
            self.logger.error(f"机器人注册失败: {e}")
            raise

    async def get_file_service_config(self) -> Dict[str, Any]:
        """获取文件服务配置（包含密钥）

        Returns:
            包含文件服务配置的字典，格式：
            {
                "errCode": 0,
                "data": {
                    "access_key_id": "文件服务访问密钥ID",
                    "access_key_secret": "文件服务访问密钥",
                    "bucket_name": "文件桶名称",
                    "endpoint": "文件服务端点",
                    "region": "服务区域",
                    "expires_at": 密钥过期时间戳
                }
            }
        """
        data = {"api_key": self.api_key, "api_secret": self.api_secret}

        try:
            session = await self._get_session()
            url = f"{self.base_url}/uni-im-co/getFileServiceConfig"

            self.logger.debug(f"获取文件服务配置: {url}")

            async with session.post(url, json=data) as resp:
                if resp.status != 200:
                    raise Exception(f"HTTP请求失败: {resp.status}")

                result = await resp.json()
                self.logger.debug(f"文件服务配置响应: {result}")

                if result.get("errCode") != 0:
                    raise Exception(
                        f"获取文件服务配置失败: {result.get('errMsg', '未知错误')}"
                    )

                return result

        except Exception as e:
            self.logger.error(f"获取文件服务配置失败: {e}")
            raise

    async def get_robot_info(self) -> Dict[str, Any]:
        """获取智能体信息（包含RabbitMQ访问令牌）

        Returns:
            包含智能体信息和RabbitMQ配置的字典，格式：
            {
                "errCode": 0,
                "data": {
                    "robot_id": "智能体ID",
                    "name": "智能体名称",
                    "queue_name": "RabbitMQ队列名",
                    "rabbitmq_token": "JWT访问令牌",
                    "token_expires_at": 令牌过期时间戳,
                    "rabbitmq_config": {
                        "host": "RabbitMQ主机",
                        "port": 端口,
                        "vhost": "虚拟主机",
                        "username": "用户名",
                        "password": "密码"
                    }
                }
            }
        """
        data = {"api_key": self.api_key, "api_secret": self.api_secret}

        try:
            session = await self._get_session()
            url = f"{self.base_url}/uni-im-co/getRobotInfoByApiKey"

            self.logger.debug(f"获取智能体信息: {url}")

            async with session.post(url, json=data) as resp:
                if resp.status != 200:
                    raise Exception(f"HTTP请求失败: {resp.status}")

                result = await resp.json()
                self.logger.debug(f"智能体信息响应: {result}")
                return result

        except Exception as e:
            self.logger.error(f"获取智能体信息失败: {e}")
            raise

    async def get_conversation_context(self, conversation_id: str) -> Dict[str, Any]:
        """获取会话上下文

        Args:
            conversation_id: 会话ID

        Returns:
            会话上下文信息
        """
        # 准备请求数据
        data = {"conversation_id": conversation_id}
        signature = sign_data(conversation_id, self.api_secret)

        request_data = {**data, "api_key": self.api_key, "signature": signature}

        try:
            session = await self._get_session()
            url = f"{self.base_url}/uni-im-co/getConversationContext"

            self.logger.debug(f"获取会话上下文: {conversation_id}")

            async with session.post(url, json=request_data) as resp:
                if resp.status != 200:
                    raise Exception(f"HTTP请求失败: {resp.status}")

                result = await resp.json()

                if result.get("errCode") != 0:
                    raise Exception(
                        f"获取会话上下文失败: {result.get('errMsg', '未知错误')}"
                    )

                return result.get("data", {})

        except Exception as e:
            self.logger.error(f"获取会话上下文失败: {e}")
            raise

    async def send_response(
        self, conversation_id: str, response: Response, to_uid: str
    ):
        """发送响应消息到平台

        Args:
            conversation_id: 会话ID
            response: 响应对象
            to_uid: 目标用户ID
        """
        # 准备响应数据
        response_data = {
            "conversation_id": conversation_id,
            "response": {**response.to_platform_format(), "to_uid": to_uid},
        }

        # 生成签名
        payload = json.dumps(response_data, ensure_ascii=False, separators=(",", ":"))
        signature = sign_data(payload, self.api_secret)

        request_data = {
            **response_data,
            "api_key": self.api_key,
            "signature": signature,
        }

        try:
            session = await self._get_session()
            url = f"{self.base_url}/uni-im-co/receiveSDKResponse"

            self.logger.debug(f"发送响应: {conversation_id} -> {to_uid}")

            async with session.post(url, json=request_data) as resp:
                if resp.status != 200:
                    raise Exception(f"HTTP请求失败: {resp.status}")

                result = await resp.json()

                if result.get("errCode") != 0:
                    raise Exception(f"发送响应失败: {result.get('errMsg', '未知错误')}")

                self.logger.debug("响应发送成功")

        except Exception as e:
            self.logger.error(f"发送响应失败: {e}")
            raise

    async def __aenter__(self):
        """异步上下文管理器入口"""
        return self

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        """异步上下文管理器出口"""
        await self.close()



#!/usr/bin/env python3
"""Example of using CloudFunctionClient to retrieve deployment configuration.

This example demonstrates:
1. Creating a CloudFunctionClient instance
2. Retrieving deployment configuration from cloud function
3. Handling errors (authentication, network, configuration)
4. Using the client as an async context manager
"""

import asyncio
import sys
from pathlib import Path

# Add SDK to path
sys.path.insert(0, str(Path(__file__).parent.parent))

from uni_agent_sdk.build_system import (
    AuthenticationError,
    CloudFunctionClient,
    ConfigurationError,
    NetworkError,
)
from uni_agent_sdk.build_system.config_provider import ConfigProvider


async def example_basic_usage():
    """Basic usage example."""
    print("=" * 60)
    print("Example 1: Basic Usage")
    print("=" * 60)

    # Load configuration
    config = ConfigProvider()

    try:
        appkey = config.get_robot_appkey()
        cloud_url = config.get_cloud_function_url()
    except ValueError as e:
        print(f"❌ Configuration error: {e}")
        print("\nPlease set the following environment variables:")
        print("  export ROBOT_APPKEY=your-appkey")
        print("  export CLOUD_FUNCTION_URL=http://api.example.com")
        return

    print(f"📋 Configuration:")
    print(f"   Cloud URL: {cloud_url}")
    print(f"   AppKey: {appkey[:20]}...")
    print()

    # Create client
    client = CloudFunctionClient(base_url=cloud_url)

    try:
        print("🔗 Fetching deployment configuration...")
        deploy_config = await client.get_deploy_config(appkey)

        print("✅ Configuration retrieved successfully!")
        print()
        print(f"📊 Deployment Configuration:")
        print(f"   Robot ID: {deploy_config['robot_id']}")
        print(
            f"   Registry URL: {deploy_config['registry']['url']}"
        )
        print(
            f"   Registry Username: {deploy_config['registry']['username']}"
        )
        print(
            f"   Node Server URL: {deploy_config.get('node_server', {}).get('url', 'Not configured')}"
        )

    except AuthenticationError as e:
        print(f"❌ Authentication failed: {e}")
        print("\nPlease check your ROBOT_APPKEY is correct.")

    except NetworkError as e:
        print(f"❌ Network error: {e}")
        print("\nPlease check your network connection and cloud function URL.")

    except ConfigurationError as e:
        print(f"❌ Configuration incomplete: {e}")
        print("\nPlease contact your administrator.")

    except Exception as e:
        print(f"❌ Unexpected error: {e}")


async def example_context_manager():
    """Example using context manager."""
    print("\n" + "=" * 60)
    print("Example 2: Using Context Manager")
    print("=" * 60)

    config = ConfigProvider()

    try:
        appkey = config.get_robot_appkey()
        cloud_url = config.get_cloud_function_url()
    except ValueError as e:
        print(f"❌ Configuration error: {e}")
        return

    # Use as context manager for automatic cleanup
    async with CloudFunctionClient(base_url=cloud_url) as client:
        try:
            print("🔗 Fetching configuration with context manager...")
            deploy_config = await client.get_deploy_config(appkey)

            print(f"✅ Robot ID: {deploy_config['robot_id']}")
            print("✅ Client will be automatically closed on exit")

        except Exception as e:
            print(f"❌ Error: {e}")


async def example_with_retry():
    """Example demonstrating retry behavior."""
    print("\n" + "=" * 60)
    print("Example 3: Retry Mechanism")
    print("=" * 60)

    config = ConfigProvider()

    try:
        appkey = config.get_robot_appkey()
        cloud_url = config.get_cloud_function_url()
    except ValueError as e:
        print(f"❌ Configuration error: {e}")
        return

    print("📋 Client configured with:")
    print("   Max retries: 3")
    print("   Timeout: 10 seconds")
    print("   Exponential backoff: 2^n seconds")
    print()

    # Create client with custom retry settings
    client = CloudFunctionClient(
        base_url=cloud_url, timeout=10.0, max_retries=3
    )

    try:
        print("🔗 Attempting to fetch configuration...")
        print("   (Will retry on network errors with exponential backoff)")
        deploy_config = await client.get_deploy_config(appkey)

        print(f"✅ Success! Robot ID: {deploy_config['robot_id']}")

    except NetworkError as e:
        print(f"❌ Failed after all retries: {e}")

    except Exception as e:
        print(f"❌ Error: {e}")


async def example_notify_deployment():
    """Example of notifying deployment status."""
    print("\n" + "=" * 60)
    print("Example 4: Notify Deployment")
    print("=" * 60)

    config = ConfigProvider()

    try:
        cloud_url = config.get_cloud_function_url()
    except ValueError as e:
        print(f"❌ Configuration error: {e}")
        return

    async with CloudFunctionClient(base_url=cloud_url) as client:
        try:
            deployment_data = {
                "image": "registry.example.com/robots/my-robot:1.0.0",
                "version": "1.0.0",
                "status": "deploying",
            }

            print("🚀 Notifying deployment start...")
            result = await client.notify_deployment(
                "robot-12345", deployment_data
            )

            print(f"✅ Notification sent: {result}")

        except Exception as e:
            print(f"❌ Error: {e}")


async def main():
    """Run all examples."""
    print("🚀 CloudFunctionClient Examples")
    print()

    # Run examples
    await example_basic_usage()
    await example_context_manager()
    await example_with_retry()
    await example_notify_deployment()

    print("\n" + "=" * 60)
    print("✅ All examples completed!")
    print("=" * 60)


if __name__ == "__main__":
    asyncio.run(main())



"""文件服务"""

import logging
import mimetypes
import os
import uuid
from datetime import datetime
from pathlib import Path
from typing import Any, Dict, Optional, Union

import aiohttp

from ..utils.config import Config


class FileService:
    """文件服务类

    提供文件上传、下载等功能，集成uniCloud OSS服务。
    支持从服务端动态获取文件服务密钥。
    """

    def __init__(self, config: Config):
        """初始化文件服务

        Args:
            config: 配置对象
        """
        self.config = config
        self.logger = logging.getLogger("FileService")

        # HTTP会话
        self._session: Optional[aiohttp.ClientSession] = None

        # OSS配置（初始为空，通过 set_oss_config 或 init_from_platform_config 设置）
        self._oss_config: Optional[Dict[str, Any]] = None
        self._oss_config_expires_at: Optional[int] = None

        # OSS客户端（延迟加载）
        self._oss_bucket = None

    async def _get_session(self) -> aiohttp.ClientSession:
        """获取HTTP会话"""
        if self._session is None or self._session.closed:
            self._session = aiohttp.ClientSession()
        return self._session

    def set_oss_config(self, config: Dict[str, Any], expires_at: Optional[int] = None):
        """手动设置OSS配置

        Args:
            config: OSS配置字典，包含：
                - access_key_id: 访问密钥ID
                - access_key_secret: 访问密钥
                - bucket_name: 桶名称
                - endpoint: 端点
                - base_path: 基础路径（可选）
                - region: 区域（可选）
            expires_at: 配置过期时间戳（可选）
        """
        self._oss_config = {
            "access_key_id": config.get("access_key_id"),
            "access_key_secret": config.get("access_key_secret"),
            "bucket_name": config.get("bucket_name"),
            "endpoint": config.get("endpoint"),
            "base_path": config.get("base_path", "agent-reports"),
            "region": config.get("region", ""),
        }
        self._oss_config_expires_at = expires_at
        self.logger.info(
            f"✅ OSS配置已设置: bucket={self._oss_config['bucket_name']}, endpoint={self._oss_config['endpoint']}"
        )
        if expires_at:
            self.logger.info(f"⏰ 密钥有效期: {expires_at}")

    async def init_from_platform_config(self, file_service_config: Dict[str, Any]):
        """从平台配置初始化文件服务

        Args:
            file_service_config: 来自平台API的文件服务配置
        """
        if not file_service_config:
            raise ValueError("文件服务配置不能为空")

        self.set_oss_config(
            config={
                "access_key_id": file_service_config.get("access_key_id"),
                "access_key_secret": file_service_config.get("access_key_secret"),
                "bucket_name": file_service_config.get("bucket_name"),
                "endpoint": file_service_config.get("endpoint"),
                "base_path": file_service_config.get("base_path", "agent-reports"),
                "region": file_service_config.get("region", ""),
            },
            expires_at=file_service_config.get("expires_at"),
        )
        self.logger.info("✅ 文件服务已从平台配置初始化")

    def _validate_oss_config(self):
        """验证OSS配置是否有效"""
        if self._oss_config is None:
            raise RuntimeError(
                "OSS配置未设置，请先调用 set_oss_config 或 init_from_platform_config"
            )

        required_keys = [
            "access_key_id",
            "access_key_secret",
            "bucket_name",
            "endpoint",
        ]
        for key in required_keys:
            if not self._oss_config.get(key):
                raise RuntimeError(f"OSS配置缺少必要字段: {key}")

        # 检查密钥是否过期
        if self._oss_config_expires_at:
            import time

            if time.time() > self._oss_config_expires_at:
                self.logger.warning("⚠️ OSS密钥已过期，需要重新获取")
                raise RuntimeError("OSS密钥已过期")

    def _get_oss_bucket(self):
        """获取OSS Bucket客户端（延迟加载）"""
        if self._oss_bucket is None:
            try:
                # 验证配置
                self._validate_oss_config()

                import oss2

                auth = oss2.Auth(
                    self._oss_config["access_key_id"],
                    self._oss_config["access_key_secret"],
                )
                self._oss_bucket = oss2.Bucket(
                    auth, self._oss_config["endpoint"], self._oss_config["bucket_name"]
                )
                self.logger.info(
                    f"✅ OSS客户端初始化成功: {self._oss_config['bucket_name']}"
                )
            except ImportError:
                self.logger.error("❌ OSS功能需要安装 oss2 库: pip install oss2")
                raise
            except Exception as e:
                self.logger.error(f"❌ OSS客户端初始化失败: {e}")
                raise
        return self._oss_bucket

    async def close(self):
        """关闭HTTP会话"""
        if self._session and not self._session.closed:
            await self._session.close()

    async def upload_file(
        self,
        file_path: Union[str, Path],
        filename: Optional[str] = None,
        content_type: Optional[str] = None,
        folder: str = "files",
    ) -> Dict[str, Any]:
        """上传文件到OSS

        Args:
            file_path: 本地文件路径
            filename: 指定文件名，默认使用原文件名
            content_type: MIME类型，默认自动检测
            folder: 文件夹名称

        Returns:
            上传结果，包含文件URL等信息
        """
        try:
            file_path = Path(file_path)
            if not file_path.exists():
                raise FileNotFoundError(f"文件不存在: {file_path}")

            # 确定文件名和MIME类型
            filename = filename or file_path.name
            if not content_type:
                content_type, _ = mimetypes.guess_type(str(file_path))
                content_type = content_type or "application/octet-stream"

            self.logger.info(f"上传文件到OSS: {filename} ({content_type})")

            # 读取文件内容
            with open(file_path, "rb") as f:
                file_data = f.read()

            # 使用OSS上传
            return await self.upload_bytes_to_oss(
                content=file_data,
                filename=filename,
                content_type=content_type,
                folder=folder,
            )

        except Exception as e:
            self.logger.error(f"上传文件失败: {e}")
            raise

    async def upload_html_to_oss(
        self, html_content: str, filename: Optional[str] = None, folder: str = "reports"
    ) -> Dict[str, Any]:
        """上传HTML内容到OSS，设置正确的预览头

        Args:
            html_content: HTML内容字符串
            filename: 文件名（可选，会自动生成）
            folder: 文件夹名称

        Returns:
            包含上传结果的字典
        """
        try:
            # 生成文件名
            if not filename:
                timestamp = datetime.now().strftime("%Y%m%d_%H%M%S")
                random_id = str(uuid.uuid4())[:8]
                filename = f"report_{timestamp}_{random_id}.html"

            # 确保文件名以.html结尾
            if not filename.endswith(".html"):
                filename += ".html"

            # 验证配置
            self._validate_oss_config()

            # 生成文件路径
            file_key = f"{self._oss_config['base_path']}/{folder}/{filename}"

            self.logger.info(f"开始上传HTML到OSS: {file_key}")

            # 获取OSS客户端
            bucket = self._get_oss_bucket()

            # 设置HTTP头，确保浏览器预览而非下载
            headers = {
                "Content-Type": "text/html; charset=utf-8",
                "Content-Disposition": 'inline; filename="agent-report.html"',
                "Cache-Control": "max-age=3600",
            }

            # 上传文件
            result = bucket.put_object(
                file_key, html_content.encode("utf-8"), headers=headers
            )

            if result.status == 200:
                # 生成访问URL
                public_url = f"https://{self._oss_config['bucket_name']}.{self._oss_config['endpoint']}/{file_key}"

                # 验证文件是否存在
                if bucket.object_exists(file_key):
                    # 获取文件信息
                    info = bucket.head_object(file_key)

                    self.logger.info(f"HTML报告上传成功: {public_url}")

                    return {
                        "success": True,
                        "file_url": public_url,
                        "url": public_url,  # 兼容现有接口
                        "file_key": file_key,
                        "filename": filename,
                        "size": info.content_length,
                        "content_type": info.content_type,
                        "upload_time": datetime.now().isoformat(),
                    }
                else:
                    raise Exception("文件上传后验证失败")
            else:
                raise Exception(f"上传失败，状态码: {result.status}")

        except Exception as e:
            self.logger.error(f"HTML报告上传失败: {e}")
            return {"success": False, "error": str(e), "file_url": None, "url": None}

    async def upload_bytes_to_oss(
        self,
        content: bytes,
        filename: str,
        content_type: Optional[str] = None,
        folder: str = "files",
    ) -> Dict[str, Any]:
        """上传字节内容到OSS

        Args:
            content: 字节内容
            filename: 文件名
            content_type: 内容类型
            folder: 文件夹名称

        Returns:
            上传结果
        """
        try:
            # 验证配置
            self._validate_oss_config()

            # 检测Content-Type
            if not content_type:
                content_type = self.get_mime_type(filename)

            # 生成文件路径
            timestamp = datetime.now().strftime("%Y%m%d_%H%M%S")
            random_id = str(uuid.uuid4())[:8]
            safe_filename = f"{timestamp}_{random_id}_{filename}"
            file_key = f"{self._oss_config['base_path']}/{folder}/{safe_filename}"

            self.logger.info(f"开始上传文件到OSS: {file_key}")

            # 获取OSS客户端
            bucket = self._get_oss_bucket()

            # 设置HTTP头
            headers = {
                "Content-Type": content_type,
                "Content-Disposition": f'inline; filename="{filename}"',
            }

            # 对于HTML文件，特别设置预览头
            if filename.lower().endswith(".html"):
                headers["Content-Disposition"] = 'inline; filename="agent-report.html"'

            # 上传文件
            result = bucket.put_object(file_key, content, headers=headers)

            if result.status == 200:
                public_url = f"https://{self._oss_config['bucket_name']}.{self._oss_config['endpoint']}/{file_key}"

                return {
                    "success": True,
                    "file_url": public_url,
                    "url": public_url,
                    "file_key": file_key,
                    "filename": safe_filename,
                    "original_filename": filename,
                    "size": len(content),
                    "content_type": content_type,
                    "upload_time": datetime.now().isoformat(),
                }
            else:
                raise Exception(f"上传失败，状态码: {result.status}")

        except Exception as e:
            self.logger.error(f"文件上传失败: {e}")
            return {"success": False, "error": str(e), "file_url": None, "url": None}

    async def download_file(
        self, file_url: str, save_path: Optional[Union[str, Path]] = None
    ) -> Path:
        """下载文件

        Args:
            file_url: 文件URL
            save_path: 保存路径，默认保存到临时目录

        Returns:
            下载文件的本地路径
        """
        try:
            session = await self._get_session()

            self.logger.info(f"下载文件: {file_url}")

            async with session.get(file_url) as resp:
                if resp.status != 200:
                    raise Exception(f"下载失败: HTTP {resp.status}")

                # 确定保存路径
                if save_path is None:
                    filename = os.path.basename(file_url.split("?")[0])
                    save_path = Path.cwd() / "downloads" / filename
                else:
                    save_path = Path(save_path)

                # 创建目录
                save_path.parent.mkdir(parents=True, exist_ok=True)

                # 写入文件
                with open(save_path, "wb") as f:
                    async for chunk in resp.content.iter_chunked(8192):
                        f.write(chunk)

                self.logger.info(f"文件已保存到: {save_path}")
                return save_path

        except Exception as e:
            self.logger.error(f"下载文件失败: {e}")
            raise

    async def get_file_info(self, file_url: str) -> Dict[str, Any]:
        """获取文件信息

        Args:
            file_url: 文件URL

        Returns:
            文件信息
        """
        try:
            session = await self._get_session()

            async with session.head(file_url) as resp:
                if resp.status != 200:
                    raise Exception(f"获取文件信息失败: HTTP {resp.status}")

                return {
                    "url": file_url,
                    "content_type": resp.headers.get("Content-Type"),
                    "content_length": int(resp.headers.get("Content-Length", 0)),
                    "last_modified": resp.headers.get("Last-Modified"),
                }

        except Exception as e:
            self.logger.error(f"获取文件信息失败: {e}")
            raise

    def get_mime_type(self, filename: str) -> str:
        """获取文件MIME类型

        Args:
            filename: 文件名

        Returns:
            MIME类型
        """
        mime_type, _ = mimetypes.guess_type(filename)
        return mime_type or "application/octet-stream"

    def is_image(self, filename: str) -> bool:
        """判断是否为图片文件"""
        mime_type = self.get_mime_type(filename)
        return mime_type.startswith("image/")

    def is_video(self, filename: str) -> bool:
        """判断是否为视频文件"""
        mime_type = self.get_mime_type(filename)
        return mime_type.startswith("video/")

    def is_audio(self, filename: str) -> bool:
        """判断是否为音频文件"""
        mime_type = self.get_mime_type(filename)
        return mime_type.startswith("audio/")

    async def __aenter__(self):
        """异步上下文管理器入口"""
        return self

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        """异步上下文管理器出口"""
        await self.close()
